package App::zerogap ;  
our $VERSION = '0.014' ; 
our $DATE = '2024-11-23T01:29+09:00' ; 

=encoding utf8

=head1 NAME

App::zerogap - TSVファイルの各列が何桁のものが何件あったかを、行列状に示す。

=head1 SYNOPSIS

This module provides a Unix-like command `F<zerogap>'. 

=head1 DESCRIPTION

=head1 SEE ALSO

zerogap --help
man zerogap
perldoc zerogap

=cut

1 ;
